/*******************************************************************************
*
*                        USING TIMER 0 IN FAST PWM MODE
*                        ------------------------------
*
*   Filename:                                    
*   Autor:                  David Kress
*
*   Version:                1.0
*   Date:                   10.11.2014
*   Built with:             ATMEL AVR Studio 4.14 and AVR-GCC; Optimization -01
*
*   Description:            This programm is a simple example how to operate
*                           Timer 0 in fast PWM mode. The duty cycle is
*                           set to 64.
*                           
*                           0 = 0%
*                           128 = 50%
*                           255 = 100%
*
*   What you can learn:     - Start Timer 0 in fast pwm mode
*                           - Set a duty cycle
*
*   Clock source:           - Any clock
*
*   Recommended             - High: 0x99
*   Fuse settings:          - Low:  0xE1
*
*
*
*   Schematic:       ___________________
*                   |      ATMEGA32     |
*          Vcc ---->|Vcc                |
*          Vcc ---->|RESET              |
*                   |                   |
*          GND ---->|GND                |
*                   |                   |
*                   |                PB3|----> Fast PWM out
*                   |                   |
*                   |                   |
*                   |                   |
*                   |                   |
*
*******************************************************************************/


#include <avr/io.h>

int main(void)
{

    DDRB = 0x08;                         // Setup PB3 as output
    
    TCCR0 |= (1<<WGM00)|(1<<WGM01)       // Start timer0 without
             |(1<<COM01)|(1<<CS00);      // prescaler in non 
                                         // inverting fast PWM 
                                         // mode. Connect OC0 in
                                         // non-inverting mode
				
    OCR0=64;                             // Set Dutycycle to 25%
  
    for(;;);                             // Endless loop;
                                         // main() will never be left

    return 0;                            // This line will never be executed

}
